@@ -62,7 +62,7 @@ def load_sample_data(name="bradypus"):
         file_path = os.path.join(package_dir, "data", "bradypus.csv.gz")
         df = pd.read_csv(file_path, compression="gzip").astype("int64")
         y = df["presence"].astype("int8")
-        x = df[df.columns[1:]].astype({"ecoreg": "category"})
+        x = df.drop(columns=["presence"]).astype({"ecoreg": "category"})
         return x, y
 
 
@@ -105,7 +105,14 @@ def load_object(path, compressed=True):
 
 
 def create_output_raster_profile(
-    raster_paths, template_idx, windowed=True, nodata=None, compress=None, driver="GTiff", bigtiff=True, dtype="float32"
+    raster_paths,
+    template_idx=0,
+    windowed=True,
+    nodata=None,
+    compress=None,
+    driver="GTiff",
+    bigtiff=True,
+    dtype="float32",
 ):
     """Gets parameters for windowed reading/writing to output rasters.
 
@@ -170,7 +177,7 @@ def check_raster_alignment(raster_paths):
         raster_paths: a list of raster covariate paths
 
     Returns:
-        Boolean: indicates wither all rasters align
+        Boolean: indicates whether all rasters align
     """
     first = raster_paths[0]
     rest = raster_paths[1:]
@@ -239,3 +246,35 @@ def n_digits(number):
         order = np.floor(np.log10(number)).astype(int) + 1
 
     return order
+
+
+def count_raster_bands(raster_paths):
+    """Returns the total number of bands from a list of rasters.
+
+    Args:
+        raster_paths: List of raster data file paths.
+
+    Returns:
+        n_bands: Int of the band count.
+    """
+    n_bands = 0
+    for path in raster_paths:
+        with rio.open(path) as src:
+            n_bands += src.count
+
+    return n_bands
+
+
+def make_band_labels(n_bands):
+    """Creates a list of band names to assign as dataframe columns.
+
+    Args:
+        n_bands: Int of the number of raster bands to create labels for.
+
+    Returns:
+        labels: List of column labels.
+    """
+    n_zeros = n_digits(n_bands)
+    labels = ["band_{band_number:0{n_zeros}d}".format(band_number=i + 1, n_zeros=n_zeros) for i in range(n_bands)]
+
+    return labels
